@@ -2,7 +2,7 @@
 #
 # django-codenerix-payments
 #
-# Copyright 2017 Centrologic Computational Logistic Center S.L.
+# Codenerix GNU
 #
 # Project URL : http://www.codenerix.com
 #
@@ -32,16 +32,18 @@ from Crypto.Hash import HMAC, SHA256
 # from suds.client import Client as SOAPClient
 
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.conf import settings
 from django.urls import reverse, resolve
 from django.utils import timezone
-from django.utils.encoding import smart_text
+from django.utils.encoding import smart_str
 from django.core.validators import MaxValueValidator
 
 from codenerix.models import CodenerixModel
 from codenerix.helpers import CodenerixEncoder
 
+CURRENCY_MAX_DIGITS = getattr(settings, 'CDNX_INVOICING_CURRENCY_MAX_DIGITS', 10)
+CURRENCY_DECIMAL_PLACES = getattr(settings, 'CDNX_INVOICING_CURRENCY_DECIMAL_PLACES', 2)
 
 PAYMENT_PROTOCOL_CHOICES = (
     ('paypal', _('Paypal')),
@@ -269,10 +271,10 @@ class Currency(CodenerixModel):
     name = models.CharField(_('Name'), max_length=15, blank=False, null=False, unique=True)
     symbol = models.CharField(_('Symbol'), max_length=2, blank=False, null=False, unique=True)
     iso4217 = models.CharField(_('ISO 4217 Code'), max_length=3, blank=False, null=False, unique=True)
-    price = models.FloatField(_('Price'), blank=False, null=False)
+    price = models.DecimalField(_('Price'), blank=False, null=False, max_digits=CURRENCY_MAX_DIGITS, decimal_places=CURRENCY_DECIMAL_PLACES)
 
     def __unicode__(self):
-        return u"{0} ({1})".format(smart_text(self.name), smart_text(self.symbol))
+        return u"{0} ({1})".format(smart_str(self.name), smart_str(self.symbol))
 
     def __str__(self):
         return self.__unicode__()
